<?php
$TRANSLATIONS = array(
"Invalid value supplied for %s" => "Valor inválido fornecido para %s",
"Saved" => "Salvo",
"test email settings" => "testar configurações de email",
"If you received this email, the settings seem to be correct." => "Se você recebeu este e-mail, as configurações parecem estar corretas.",
"A problem occurred while sending the e-mail. Please revisit your settings." => "Ocorreu um problema ao enviar o e-mail. Por favor, reveja suas configurações.",
"Email sent" => "E-mail enviado",
"You need to set your user email before being able to send test emails." => "Você precisa configurar seu e-mail de usuário antes de ser capaz de enviar e-mails de teste.",
"Send mode" => "Modo enviar",
"Encryption" => "Criptografia",
"Authentication method" => "Método de autenticação",
"Unable to load list from App Store" => "Não foi possível carregar lista da App Store",
"Authentication error" => "Erro de autenticação",
"Your full name has been changed." => "Seu nome completo foi alterado.",
"Unable to change full name" => "Não é possível alterar o nome completo",
"Group already exists" => "O Grupo já existe",
"Unable to add group" => "Não foi possível adicionar grupo",
"Files decrypted successfully" => "Arquivos descriptografados com sucesso",
"Couldn't decrypt your files, please check your owncloud.log or ask your administrator" => "Não foi possível descriptografar os arquivos, verifique a sua owncloud.log ou pergunte ao seu administrador",
"Couldn't decrypt your files, check your password and try again" => "Não foi possível descriptografar os arquivos, verifique sua senha e tente novamente",
"Encryption keys deleted permanently" => "Chaves de criptografia excluídas permanentemente",
"Couldn't permanently delete your encryption keys, please check your owncloud.log or ask your administrator" => "Não foi possível excluir permanentemente suas chaves de criptografia, por favor, verifique o seu owncloud.log ou pergunte ao seu administrador",
"Couldn't remove app." => "Não foi possível remover aplicativos.",
"Email saved" => "E-mail salvo",
"Invalid email" => "E-mail inválido",
"Unable to delete group" => "Não foi possível remover grupo",
"Unable to delete user" => "Não foi possível remover usuário",
"Backups restored successfully" => "Backup restaurado com sucesso",
"Couldn't restore your encryption keys, please check your owncloud.log or ask your administrator" => "Não foi possível salvar as chaves de criptografia, por favor, verifique o seu owncloud.log ou pergunte ao seu administrador",
"Language changed" => "Idioma alterado",
"Invalid request" => "Pedido inválido",
"Admins can't remove themself from the admin group" => "Administradores não pode remover a si mesmos do grupo de administração",
"Unable to add user to group %s" => "Não foi possível adicionar usuário ao grupo %s",
"Unable to remove user from group %s" => "Não foi possível remover usuário do grupo %s",
"Couldn't update app." => "Não foi possível atualizar a app.",
"Wrong password" => "Senha errada",
"No user supplied" => "Nenhum usuário fornecido",
"Please provide an admin recovery password, otherwise all user data will be lost" => "Por favor, forneça uma senha de recuperação admin, caso contrário todos os dados do usuário serão perdidos",
"Wrong admin recovery password. Please check the password and try again." => "Senha de recuperação do administrador errada. Por favor verifique a senha e tente novamente.",
"Back-end doesn't support password change, but the users encryption key was successfully updated." => "Back-end não suporta alteração de senha, mas a chave de criptografia de usuários foi atualizado com sucesso....",
"Unable to change password" => "Impossível modificar senha",
"Sending..." => "Enviando...",
"User Documentation" => "Documentação de Usuário",
"Admin Documentation" => "Documentação de Administrador",
"Update to {appversion}" => "Atualizar para {appversion}",
"Uninstall App" => "Desinstalar Aplicativo",
"Disable" => "Desabilitar",
"Enable" => "Habilitar",
"Please wait...." => "Por favor, aguarde...",
"Error while disabling app" => "Erro enquanto desabilitava o aplicativo",
"Error while enabling app" => "Erro enquanto habilitava o aplicativo",
"Updating...." => "Atualizando...",
"Error while updating app" => "Erro ao atualizar aplicativo",
"Error" => "Erro",
"Update" => "Atualizar",
"Updated" => "Atualizado",
"Uninstalling ...." => "Desinstalando ...",
"Error while uninstalling app" => "Erro enquanto desinstalava aplicativo",
"Uninstall" => "Desinstalar",
"Select a profile picture" => "Selecione uma imagem para o perfil",
"Very weak password" => "Senha muito fraca",
"Weak password" => "Senha fraca",
"So-so password" => "Senha mais ou menos",
"Good password" => "Boa senha",
"Strong password" => "Senha forte",
"Decrypting files... Please wait, this can take some time." => "Decriptando arquivos... Por favor aguarde, isso pode levar algum tempo.",
"Delete encryption keys permanently." => "Eliminando a chave de criptografia permanentemente.",
"Restore encryption keys." => "Restaurar chave de criptografia.",
"Unable to delete {objName}" => "Não é possível excluir {objName}",
"Error creating group" => "Erro ao criar grupo",
"A valid group name must be provided" => "Um nome de grupo válido deve ser fornecido",
"deleted {groupName}" => "eliminado {groupName}",
"undo" => "desfazer",
"Groups" => "Grupos",
"Group Admin" => "Grupo Administrativo",
"Delete" => "Excluir",
"never" => "nunca",
"deleted {userName}" => "eliminado {userName}",
"add group" => "adicionar grupo",
"A valid username must be provided" => "Forneça um nome de usuário válido",
"Error creating user" => "Erro ao criar usuário",
"A valid password must be provided" => "Forneça uma senha válida",
"Warning: Home directory for user \"{user}\" already exists" => "Aviso: O diretório home para o usuário \"{user}\" já existe",
"__language_name__" => "__language_name__",
"Everything (fatal issues, errors, warnings, info, debug)" => "Tudo (questões fatais, erros, avisos, informações, depuração)",
"Info, warnings, errors and fatal issues" => "Informações, avisos, erros e problemas fatais",
"Warnings, errors and fatal issues" => "Avisos, erros e problemas fatais",
"Errors and fatal issues" => "Erros e problemas fatais",
"Fatal issues only" => "Somente questões fatais",
"None" => "Nada",
"Login" => "Login",
"Plain" => "Plano",
"NT LAN Manager" => "Gerenciador NT LAN",
"SSL" => "SSL",
"TLS" => "TLS",
"Security Warning" => "Aviso de Segurança",
"You are accessing %s via HTTP. We strongly suggest you configure your server to require using HTTPS instead." => "Você está acessando %s via HTTP. Sugerimos você configurar o servidor para exigir o uso de HTTPS em seu lugar.",
"Your data directory and your files are probably accessible from the internet. The .htaccess file is not working. We strongly suggest that you configure your webserver in a way that the data directory is no longer accessible or you move the data directory outside the webserver document root." => "Seu diretório de dados e seus arquivos são, provavelmente, acessíveis a partir da internet. O arquivo htaccess. não está funcionando. Nós sugerimos fortemente que você configure o seu servidor web de uma forma que o diretório de dados não esteja mais acessível ou mova o diretório de dados para fora do raiz do servidor.",
"Setup Warning" => "Aviso de Configuração",
"Your web server is not yet properly setup to allow files synchronization because the WebDAV interface seems to be broken." => "Seu servidor web não está configurado corretamente para permitir sincronização de arquivos porque a interface WebDAV parece não estar funcionando.",
"Please double check the <a href=\"%s\">installation guides</a>." => "Por favor, verifique os <a href='%s'>guias de instalação</a>.",
"PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." => "PHP é, aparentemente, a configuração para retirar blocos doc inline. Isso fará com que vários aplicativos do núcleo fiquem inacessíveis.",
"This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." => "Isso provavelmente é causado por uma cache/acelerador, como Zend OPcache ou eAccelerator.",
"Database Performance Info" => "Informações de Desempenho do Banco de Dados",
"SQLite is used as database. For larger installations we recommend to change this. To migrate to another database use the command line tool: 'occ db:convert-type'" => "SQLite é usada como base de dados. Para grandes instalações recomendamos mudar isso. Para migrar para outro banco de dados usar a ferramenta de linha de comando: 'occ db: converter-type'",
"Module 'fileinfo' missing" => "Módulo 'fileinfo' faltando",
"The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." => "O módulo PHP 'fileinfo' está faltando. Recomendamos que ative este módulo para obter uma melhor detecção do tipo de mídia (mime-type).",
"Your PHP version is outdated" => "Sua versão de PHP está desatualizada",
"Your PHP version is outdated. We strongly recommend to update to 5.3.8 or newer because older versions are known to be broken. It is possible that this installation is not working correctly." => "A sua versão do PHP está desatualizada. Recomendamos a atualização para 5.3.8 ou mais recente, pois as versões mais antigas são conhecidas por serem quebradas. É possível que esta instalação não esteja funcionando corretamente.",
"Locale not working" => "Localização não funcionando",
"System locale can not be set to a one which supports UTF-8." => "Localidade do sistema não pode ser definido como um que suporta UTF-8.",
"This means that there might be problems with certain characters in file names." => "Isso significa que pode haver problemas com certos caracteres nos nomes de arquivo.",
"We strongly suggest to install the required packages on your system to support one of the following locales: %s." => "Nós fortemente sugerimos instalar os pacotes necessários no seu sistema para suportar uma das seguintes localidades: %s.",
"Internet connection not working" => "Sem conexão com a internet",
"This server has no working internet connection. This means that some of the features like mounting of external storage, notifications about updates or installation of 3rd party apps don´t work. Accessing files from remote and sending of notification emails might also not work. We suggest to enable internet connection for this server if you want to have all features." => "Este servidor não tem conexão com a internet. Isso significa que algumas das características como a montagem de armazenamento externo, notificações sobre atualizações ou instalação de aplicativos de 3ºs terceiros não funcionam. Acessar arquivos remotamente e envio de e-mails de notificação também não podem funcionar. Sugerimos permitir conexão com a internet para esse servidor, se você deseja ter todas as funcionalidades.",
"Cron" => "Cron",
"Last cron was executed at %s." => "Último cron foi executado em %s.",
"Last cron was executed at %s. This is more than an hour ago, something seems wrong." => "Última cron foi executado em %s. Isso é, mais de uma hora atrás, algo parece errado.",
"Cron was not executed yet!" => "Cron não foi executado ainda!",
"Execute one task with each page loaded" => "Execute uma tarefa com cada página carregada",
"cron.php is registered at a webcron service to call cron.php every 15 minutes over http." => "cron.php está registrado no serviço webcron para chamar cron.php a cada 15 minutos sobre http.",
"Use system's cron service to call the cron.php file every 15 minutes." => "Use o sistema de serviço cron para chamar o arquivo cron.php a cada 15 minutos.",
"Sharing" => "Compartilhamento",
"Allow apps to use the Share API" => "Permitir que aplicativos usem a API de Compartilhamento",
"Allow users to share via link" => "Permitir que os usuários compartilhem por link",
"Enforce password protection" => "Reforce a proteção por senha",
"Allow public uploads" => "Permitir envio público",
"Set default expiration date" => "Configurar a data de expiração",
"Expire after " => "Expirar depois de",
"days" => "dias",
"Enforce expiration date" => "Fazer cumprir a data de expiração",
"Allow resharing" => "Permitir recompartilhamento",
"Restrict users to only share with users in their groups" => "Restringir os usuários a compartilhar somente com os usuários em seus grupos",
"Allow users to send mail notification for shared files" => "Permitir aos usuários enviar notificação de email para arquivos compartilhados",
"Exclude groups from sharing" => "Excluir grupos de compartilhamento",
"These groups will still be able to receive shares, but not to initiate them." => "Esses grupos ainda serão capazes de receber compartilhamentos, mas não para iniciá-los.",
"Security" => "Segurança",
"Enforce HTTPS" => "Forçar HTTPS",
"Forces the clients to connect to %s via an encrypted connection." => "Obrigar os clientes que se conectem a %s através de uma conexão criptografada.",
"Please connect to your %s via HTTPS to enable or disable the SSL enforcement." => "Por favor, se conectar ao seu %s via HTTPS para forçar ativar ou desativar SSL.",
"Email Server" => "Servidor de Email",
"This is used for sending out notifications." => "Isto é usado para o envio de notificações.",
"From address" => "Do Endereço",
"mail" => "email",
"Authentication required" => "Autenticação é requerida",
"Server address" => "Endereço do servidor",
"Port" => "Porta",
"Credentials" => "Credenciais",
"SMTP Username" => "Nome do Usuário SMTP",
"SMTP Password" => "Senha SMTP",
"Test email settings" => "Configurações de e-mail de teste",
"Send email" => "Enviar email",
"Log" => "Registro",
"Log level" => "Nível de registro",
"More" => "Mais",
"Less" => "Menos",
"Version" => "Versão",
"Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "Desenvolvido pela <a href=\"http://ownCloud.org/contact\" target=\"_blank\">comunidade ownCloud</a>, o <a href=\"https://github.com/owncloud\" target=\"_blank\">código fonte</a> está licenciado sob <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>.",
"Add your App" => "Adicione seu Aplicativo",
"More Apps" => "Mais Apps",
"Select an App" => "Selecione um Aplicativo",
"Documentation:" => "Documentação:",
"See application page at apps.owncloud.com" => "Ver página do aplicativo em apps.owncloud.com",
"See application website" => "Consulte o site aplicação",
"<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "<span class=\"licence\"></span>-licenciado por <span class=\"author\"></span>",
"Enable only for specific groups" => "Ativar apenas para grupos específicos",
"All" => "Todos",
"Administrator Documentation" => "Documentação de Administrador",
"Online Documentation" => "Documentação Online",
"Forum" => "Fórum",
"Bugtracker" => "Rastreador de Bugs",
"Commercial Support" => "Suporte Comercial",
"Get the apps to sync your files" => "Faça com que os apps sincronizem seus arquivos",
"Show First Run Wizard again" => "Mostrar Assistente de Primeira Execução novamente",
"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "Você usou <strong>%s</strong> do seu espaço de <strong>%s</strong>",
"Password" => "Senha",
"Your password was changed" => "Sua senha foi alterada",
"Unable to change your password" => "Não é possivel alterar a sua senha",
"Current password" => "Senha atual",
"New password" => "Nova senha",
"Change password" => "Alterar senha",
"Full Name" => "Nome Completo",
"Email" => "E-mail",
"Your email address" => "Seu endereço de e-mail",
"Fill in an email address to enable password recovery and receive notifications" => "Preencha com um e-mail para permitir a recuperação de senha e receber notificações",
"Profile picture" => "Imagem para o perfil",
"Upload new" => "Enviar nova foto",
"Select new from Files" => "Selecinar uma nova dos Arquivos",
"Remove image" => "Remover imagem",
"Either png or jpg. Ideally square but you will be able to crop it." => "Ou png ou jpg. O ideal é quadrado, mas você vai ser capaz de cortá-la.",
"Your avatar is provided by your original account." => "Seu avatar é fornecido por sua conta original.",
"Cancel" => "Cancelar",
"Choose as profile image" => "Escolha como imagem para o perfil",
"Language" => "Idioma",
"Help translate" => "Ajude a traduzir",
"The encryption app is no longer enabled, please decrypt all your files" => "O aplicativo de criptografia não está habilitado, por favor descriptar todos os seus arquivos",
"Log-in password" => "Senha de login",
"Decrypt all Files" => "Descriptografar todos os Arquivos",
"Your encryption keys are moved to a backup location. If something went wrong you can restore the keys. Only delete them permanently if you are sure that all files are decrypted correctly." => "Suas chaves de criptografia forão movidas para o local de backup. Se alguma coisa deu errado, você pode salvar as chaves. Só excluí-las permanentemente se você tiver certeza de que  todos os arquivos forão descriptografados corretamente.",
"Restore Encryption Keys" => "Restaurar Chaves de Criptografia",
"Delete Encryption Keys" => "Eliminar Chaves de Criptografia",
"Login Name" => "Nome de Login",
"Create" => "Criar",
"Admin Recovery Password" => "Recuperação da Senha do Administrador",
"Enter the recovery password in order to recover the users files during password change" => "Digite a senha de recuperação para recuperar os arquivos dos usuários durante a mudança de senha.",
"Search Users and Groups" => "Pesquisar Usuários e Grupos",
"Add Group" => "Adicionar Grupo",
"Group" => "Grupo",
"Everyone" => "Para todos",
"Admins" => "Administradores",
"Default Quota" => "Quota Padrão",
"Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" => "Por favor insira cota de armazenamento (ex: \"512\" ou \"12 GB\")",
"Unlimited" => "Ilimitado",
"Other" => "Outro",
"Username" => "Nome de Usuário",
"Quota" => "Cota",
"Storage Location" => "Local de Armazenamento",
"Last Login" => "Último Login",
"change full name" => "alterar nome completo",
"set new password" => "definir nova senha",
"Default" => "Padrão",
"If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwritewebroot\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" => "Se a sua instalação não estiver instalada na raiz do domínio e usa cron do sistema, pode haver problemas com a geração de URL. Para evitar esses problemas, por favor, defina a opção \"overwritewebroot\" em seu arquivo config.php para o caminho webroot de sua instalação (Sugestão: \"%s\")",
"URL generation in notification emails" => "Geração de URL em e-mails de notificação",
"Connectivity Checks" => "Verificações de Conectividade",
"No problems found" => "Nenhum problema encontrado",
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";
